@@ -10,6 +10,8 @@ use ReflectionProperty;
 
 use function sprintf;
 
+use const PHP_VERSION_ID;
+
 /** @internal */
 class ReadonlyAccessor implements PropertyAccessor
 {
@@ -26,7 +28,12 @@ class ReadonlyAccessor implements PropertyAccessor
 
     public function setValue(object $object, mixed $value): void
     {
-        if (! $this->reflectionProperty->isInitialized($object)) {
+        /* For lazy properties, skip the isInitialized() check
+           because it would trigger the initialization of the whole object. */
+        if (
+            PHP_VERSION_ID >= 80400 && $this->reflectionProperty->isLazy($object)
+            || ! $this->reflectionProperty->isInitialized($object)
+        ) {
             $this->parent->setValue($object, $value);
 
             return;
